@@ -2,7 +2,8 @@
 
 #
 # dbcoldefine.pm
-# Copyright (C) 1991-2016 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 1991-2008 by John Heidemann <johnh@isi.edu>
+# $Id$
 #
 # This program is distributed under terms of the GNU general
 # public license, version 2.  See the file COPYING
@@ -34,12 +35,6 @@ the input datastream is a correctly formatted Fsdb file.
 
 Specify the field separator.
 
-=item B<--header> H
-
-Give the columns and field separator as a full Fsdb header
-(including C<#fsdb>).
-Can only be used alone, not with other specifications.
-
 =back
 
 =for comment
@@ -156,7 +151,6 @@ sub set_defaults ($) {
     $self->SUPER::set_defaults();
     $self->{_fscode} = 'D';
     $self->{_cols} = [];
-    $self->{_header} = undef;
 }
 
 =head2 parse_options
@@ -178,8 +172,7 @@ sub parse_options ($@) {
 	'autorun!' => \$self->{_autorun},
 	'close!' => \$self->{_close},
 	'd|debug+' => \$self->{_debug},
-	'F|fs|fieldseparator|columnseparator=s' => \$self->{_fscode},
-	'header=s' => \$self->{_header},
+	'F|fs|fieldseperator=s' => \$self->{_fscode},
 	'i|input=s' => sub { $self->parse_io_option('input', @_); },
 	'log!' => \$self->{_logprog},
 	'o|output=s' => sub { $self->parse_io_option('output', @_); },
@@ -198,20 +191,9 @@ Internal: setup, parse headers.
 sub setup ($) {
     my($self) = @_;
 
-    my(@finish_args) = (-comment_handler => $self->create_pass_comments_sub);
-    if (!defined($self->{_header}) && $#{$self->{_cols}} == -1) {
-        croak($self->{_prog} . ": must specify either --header or columns.\n");
-    } elsif (defined($self->{_header}) && $#{$self->{_cols}} == -1) {
-	push(@finish_args, -header => $self->{_header});
-    } elsif (!defined($self->{_header}) && $#{$self->{_cols}} > -1) {
-	push(@finish_args, -fscode => $self->{_fscode}, -cols => $self->{_cols});
-    } else {
-        croak($self->{_prog} . ": cannot specific both --header and columns.\n");
-    };
-    
-
     # all the hard work is on the next line where we force the right codes
-    $self->finish_io_option('input', @finish_args);
+    $self->finish_io_option('input', -fscode => $self->{_fscode}, -cols => $self->{_cols},
+	-comment_handler => $self->create_pass_comments_sub);
 
     $self->finish_io_option('output', -clone => $self->{_in});
 }
@@ -236,7 +218,7 @@ sub run ($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1991-2016 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1991-2008 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
